﻿using Chaos.Modules;
using System;
using System.Drawing;
using System.IO;
using System.Reflection;
using System.Windows.Forms;

namespace Chaos.Components
{
    public class Noticon
    {
        private MainWindow _mainWindow;
        private NotifyIcon _notifyIcon;
            
        public bool Visible
        {
            get { return _notifyIcon.Visible; }
            set { _notifyIcon.Visible = value; }
        }

        public Noticon(MainWindow mainWindow)
        {
            this._mainWindow = mainWindow;

            this._notifyIcon = new NotifyIcon() { Text = "Chaos", Icon = new Icon(Assembly.GetExecutingAssembly().GetManifestResourceStream("Chaos.Images.icon.ico")) };
            this._notifyIcon.DoubleClick += Menuitem_monitor_Click;
            ContextMenu contextMenu = new ContextMenu();

            MenuItem menuitem_monitor = new MenuItem("Open monitor");
            menuitem_monitor.Click += Menuitem_monitor_Click;
            contextMenu.MenuItems.Add(menuitem_monitor);

            MenuItem menuitem_savelog = new MenuItem("Save current log");
            menuitem_savelog.Click += Menuitem_savelog_Click; ;
            contextMenu.MenuItems.Add(menuitem_savelog);

            MenuItem menuitem_viewlog = new MenuItem("View a log");
            menuitem_viewlog.Click += Menuitem_viewlog_Click; ; ;
            contextMenu.MenuItems.Add(menuitem_viewlog);

            contextMenu.MenuItems.Add(new MenuItem("-"));

            MenuItem menuitem_hooking = new MenuItem("Stop hooking");
            menuitem_hooking.Click += Menuitem_hooking_Click;
            contextMenu.MenuItems.Add(menuitem_hooking);

            contextMenu.MenuItems.Add(new MenuItem("-"));

            MenuItem menuitem_exit = new MenuItem("Exit");
            menuitem_exit.Click += Menuitem_Exit_Click;
            contextMenu.MenuItems.Add(menuitem_exit);

            this._notifyIcon.ContextMenu = contextMenu;
        }

        private void Menuitem_viewlog_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog() { Filter = "Text Files | *.txt", InitialDirectory = System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().CodeBase) };
            ofd.ShowDialog();

            if (!string.IsNullOrEmpty(ofd.FileName))
                new LogViewer(new FileInfo(ofd.FileName));
        }

        private void Menuitem_savelog_Click(object sender, EventArgs e)
        {
            SaveFileDialog sfd = new SaveFileDialog() { DefaultExt = "txt", Filter = "Text Files | *.txt", InitialDirectory = Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().CodeBase) };
            sfd.ShowDialog();

            if (!string.IsNullOrEmpty(sfd.FileName))
                File.WriteAllText(sfd.FileName, Cryptography.Encrypt(this._mainWindow.Text, "Ch@05 15 tH3 835t"));
        }

        private void Menuitem_hooking_Click(object sender, EventArgs e)
        {
            this._mainWindow.Hook.Hooking = !this._mainWindow.Hook.Hooking;
            ((MenuItem)sender).Text = $"{((bool)this._mainWindow.Hook.Hooking ? "Stop" : "Start")} hooking";
        }

        private void Menuitem_monitor_Click(object sender, EventArgs e)
        {
            this._mainWindow.Visibility = System.Windows.Visibility.Visible;
        }

        private void Menuitem_Exit_Click(object sender, EventArgs e)
        {
            this._notifyIcon.Visible = false;
            Environment.Exit(0);
        }
    }
}
